#
# spec file for package lib3ds
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname %{name}-1-3
Name:           lib3ds
Version:        1.3.0
Release:        31.13
Summary:        Import and Export of Autodesk 3DS Files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://lib3ds.sourceforge.net
Source0:        %{name}-%{version}.tar.bz2
Patch0:         lib3ds-pkgconfig.patch
Patch1:         lib3ds-mesh.c.patch
BuildRequires:  libtool
BuildRequires:  pkg-config

%description
Lib3ds is a free alternative to Autodesk's 3DS File Toolkit for
handling 3DS files. Its main goal is to simplify the creation of 3DS
import and export filters.

%package -n %{libname}
Summary:        Import and Export of Autodesk 3DS Files
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}

%description -n %{libname}
Lib3ds is a free alternative to Autodesk's 3DS File Toolkit for
handling 3DS files. Its main goal is to simplify the creation of 3DS
import and export filters.

%package devel
Summary:        Import and Export of Autodesk 3DS Files
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       glibc-devel

%description devel
Lib3ds is a free alternative to Autodesk's 3DS File Toolkit for
handling 3DS files. Its main goal is to simplify the creation of 3DS
import and export filters.

%prep
%autosetup -p1

%build
autoreconf -fvi
export CFLAGS="%{optflags}"
%configure \
    --enable-shared \
    --disable-static
%make_build

%install
rm -rf examples/.deps
%make_install
mkdir -p %{buildroot}%{_libdir}/pkgconfig/
install -m644 lib3ds.pc %{buildroot}%{_libdir}/pkgconfig/
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%files -n %{libname}
%{_libdir}/lib3ds-1.so.3*

%files devel
%doc AUTHORS README COPYING ChangeLog examples
%dir %{_includedir}/lib3ds
%{_bindir}/3dsdump
%{_includedir}/lib3ds/*.h
%{_bindir}/lib3ds-config
%{_mandir}/man1/*gz
%{_libdir}/lib3ds.so
%{_datadir}/aclocal/lib3ds.m4
%{_libdir}/pkgconfig/lib3ds.pc

%post -n %{libname}  -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%changelog
* Mon Jun  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static)
* Wed May  8 2019 olaf@aepfle.de
- Install pkgconfig into libdir instead of datadir
* Fri May 20 2016 christoph@stop.pe
- Fixed packaging of -devel package to include lib3ds.pc file (/usr/bin/lib3ds-config will not work without it).
* Mon Sep 15 2014 crrodriguez@opensuse.org
- Remove superflous buildrequires, mesa and freeglut are never used.
* Mon Aug  4 2014 tchvatal@suse.com
- Add pkgconfig patch to match Fedora behaviour:
  * lib3ds-pkgconfig.patch
- Format with spec-cleaner.
- Remove Obsoletes from openSUSE-10.2
- Add patch to fix potential CVE-2010-0280:
  * lib3ds-mesh.c.patch
* Sat Jan 12 2013 jengelh@inai.de
- Remove undesired/redundant tags/sections
- Parallel build with %%_smp_mflags
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Sun Aug 12 2007 crrodriguez@suse.de
- update to version 1.3.0
- use library packaging policy
- drop all no longer needed patches
- provide shared libraries only.
* Wed May 30 2007 pth@suse.de
- Suppress "devel file in non-devel package" error. lib3ds only
  provides a static library and headers.
- Don't compile examples, let the user do that himself if needed.
- Provide CONFIGURE_GLUT in acinclude.m4 in order to make it
  possible to run autoreconf. Remove unnecessary acconfig.h.
- modify lib3ds-no_type_punning.patch to more resemble upstream
  fix.
- (Build)Require Mesa-devel and freeglut-devel
* Thu Aug 31 2006 pth@suse.de
- Fix quoting in definition of AM_PATH_LIB3DS.
- Fix type punning to compile with strict-aliasing.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Apr 21 2004 adrian@suse.de
- compile with -fno-strict-aliasing
* Fri Dec  5 2003 adrian@suse.de
- package also examples
* Tue Apr  1 2003 adrian@suse.de
- initial package of version 1.2.0
